@@ -3,4 +3,4 @@
     directory of this source tree. *)
 
 let recoverable = ref false
-let configure ~r = recoverable := r
+let configure ~recoverable:r = recoverable := r
